#!/usr/bin/env ruby
#############################################################################
# This part of Drossellog generates the YAML-Data-Files in which the parsed #
# logfile is stored                                                         #
#############################################################################

require 'getoptlong'
require 'xhochy/drossellog/logfileparser.rb'

## Functions ##

# Explain to the user how to use Drossellog
def usage
  puts '--help, -h                 Display this help'
  puts '--file, -f <file>          The name of the file from which we take the data'
  puts '--outdir, -o <dir>         The directory where the repoert could be stored'
  puts '--indir, -i <dir>         The directory where the data could be found'
  exit
end

## Var Init ##

opts = GetoptLong.new(
  ['--help', '-h', GetoptLong::NO_ARGUMENT],
  ['--file', '-f', GetoptLong::REQUIRED_ARGUMENT],
  ['--outdir', '-o', GetoptLong::REQUIRED_ARGUMENT],
  ['--indir', '-i', GetoptLong::REQUIRED_ARGUMENT]
)

$file = ''
$outdir = ''
$indir = ''

## Main ##

opts.each do |opt, arg|
  case opt
    when '--help'
      usage()
    when '--file'
      $file = arg
    when '--outdir'
      $outdir = arg   
    when '--indir'
      $indir = arg
  end
end

# check the input

if $file.empty?
  puts 'Error: You need to specify a filename'
  puts ''
  usage()
end

if $indir.empty?
  puts 'Error: You need to a data-source directory'
  puts ''
  usage()
end

if $outdir.empty?
  $outdir = $indir
end

# make it!

puts '-> Generating daily reports'
rxp = File.join($tmp_path, File.basename($file), '*', '*', '*.xml')
files = FileList[rxp]
files.each do |f|
  date = /(\d+)\/([A-Za-z]+)\/(\d+)\.xml$/.match(f)
  puts '--> ' + date[3] + ' ' + date[2] + ' ' + date[1]
  xml = XML::Document.file(f)
  report = XhochY::Drossellog::DailyReport.new(xml.root)
end
