#!/usr/bin/env ruby
#############################################################################
# This part of Drossellog generates the YAML-Data-Files in which the parsed #
# logfile is stored                                                         #
#############################################################################

require 'getoptlong'
require 'xhochy/drossellog/logfileparser.rb'

## Functions ##

# Explain to the user how to use Drossellog
def usage
  puts '--help, -h                 Display this help'
  puts '--parse-file, -f <file>    Parse a file'
  puts '--outdir, -o <dir>         The directory where the data could be stored'
  puts '--domain, -d <domain>      The domain to which the log file belongs'
  puts '--alias, -a <domainalias>  A alias which is identical to the domain(used for detection of external referrers)'
  exit
end

## Var Init ##

opts = GetoptLong.new(
  ['--help', '-h', GetoptLong::NO_ARGUMENT],
  ['--parse-file', '-f', GetoptLong::REQUIRED_ARGUMENT],
  ['--domain', '-d', GetoptLong::REQUIRED_ARGUMENT],
  ['--alias', '-a', GetoptLong::REQUIRED_ARGUMENT],
  ['--outdir', '-o', GetoptLong::REQUIRED_ARGUMENT]
)

$domain_alias = []
$file = ''
$outdir = ''
$domain = ''
$domain_alias = []

## Main ##

opts.each do |opt, arg|
  case opt
    when '--help'
      usage()
    when '--parse-file'
      $file = arg
    when '--alias'
      $domain_alias << arg
    when '--domain'
      $domain = arg
    when '--outdir'
      $outdir = arg   
  end
end

# sure ;-), the domain is a alias of itself

$domain_alias << $domain

# check the input

if $file.empty?
  puts 'Error: You need to specify a filename'
  puts ''
  usage()
end

if $domain.empty?
  puts 'Error: You need to specify a domain'
  puts ''
  usage()
end

if $outdir.empty?
  puts 'Error: You need to specify a output directory'
  puts ''
  usage()
end

# parse it!

parser = XhochY::Drossellog::LogFileParser.new($file, $outdir)
puts 'Parsing file "' + File.basename($file) + '"...'
if parser.outdated?
  parser.cleanup_old
  parser.parse
  puts '-> Saving data'
  parser.save_data($domain, $domain_alias)
end
